@@ -308,14 +308,19 @@ class ConfigurationFile(ABC):
         return f'# `{self.name}` generated with NEMSpy {__version__}'
 
     def write(
-        self, directory: PathLike, overwrite: bool = False, include_version: bool = False
+        self, filename: PathLike, overwrite: bool = False, include_version: bool = False
     ) -> Path:
+        if not isinstance(filename, Path):
+            filename = Path(filename)
+        ensure_directory(filename.parent)
+
         output = f'{self}\n'
         if include_version:
             output = f'{self.version_header}\n{output}'
 
-        directory = ensure_directory(directory)
-        filename = directory / self.name
+        if filename.is_dir():
+            filename = filename / self.name
+            LOGGER.warning(f'creating new file "{filename}"')
 
         if filename.exists():
             LOGGER.warning(
@@ -374,9 +379,9 @@ class ModelConfigurationFile(ConfigurationFile):
         super().__init__(sequence)
 
     def write(
-        self, directory: PathLike, overwrite: bool = False, include_version: bool = False
-    ):
-        filename = super().write(directory, overwrite, include_version)
+        self, filename: PathLike, overwrite: bool = False, include_version: bool = False
+    ) -> Path:
+        filename = super().write(filename, overwrite, include_version)
         symbolic_link_filename = filename.parent / 'atm_namelist.rc'
 
         try:
@@ -385,6 +390,8 @@ class ModelConfigurationFile(ConfigurationFile):
             LOGGER.warning(f'could not create symbolic link: {error}')
             shutil.copyfile(filename, symbolic_link_filename)
 
+        return filename
+
     def __str__(self) -> str:
         duration_hours = round(self.duration / timedelta(hours=1))
         return '\n'.join(
